import pytest
from unittest.mock import AsyncMock

from mcp_dagster.server import DagsterGraphqlClient


@pytest.fixture
def mock_client():
    client = DagsterGraphqlClient()
    client.execute_graphql = AsyncMock()
    return client


@pytest.mark.asyncio
async def test_list_repositories_success(mock_client):
    # Setup mock response
    mock_client.execute_graphql.return_value = {
        "data": {
            "repositoriesOrError": {
                "nodes": [{"name": "test_repo", "location": {"name": "test_location"}}]
            }
        }
    }

    # Execute method
    result = await mock_client.list_repositories()

    # Assert result
    assert result == {
        "repositories": [{"name": "test_repo", "location": "test_location"}]
    }


@pytest.mark.asyncio
async def test_list_repositories_error(mock_client):
    # Setup mock error response
    mock_client.execute_graphql.return_value = {
        "errors": [{"message": "Connection error"}]
    }

    # Execute method
    result = await mock_client.list_repositories()

    # Assert error is returned
    assert result == {"error": "Connection error"}


@pytest.mark.asyncio
async def test_list_jobs(mock_client):
    # Setup mock response
    mock_client.execute_graphql.return_value = {
        "data": {
            "repositoryOrError": {
                "jobs": [
                    {"name": "job1", "description": "First job"},
                    {"name": "job2", "description": "Second job"},
                ]
            }
        }
    }

    # Execute method
    result = await mock_client.list_jobs("test_location", "test_repo")

    # Assert result
    assert result == {
        "jobs": [
            {"name": "job1", "description": "First job"},
            {"name": "job2", "description": "Second job"},
        ]
    }


@pytest.mark.asyncio
async def test_get_run_info(mock_client):
    # Setup mock response
    mock_client.execute_graphql.return_value = {
        "data": {
            "runOrError": {
                "runId": "test_run_id",
                "status": "SUCCESS",
                "jobName": "test_job",
                "startTime": 1622548800,
                "endTime": 1622549000,
                "tags": [{"key": "tag1", "value": "value1"}],
            }
        }
    }

    # Execute method
    result = await mock_client.get_run_info("test_run_id")

    # Assert result
    assert result == {
        "run": {
            "runId": "test_run_id",
            "status": "SUCCESS",
            "jobName": "test_job",
            "startTime": 1622548800,
            "endTime": 1622549000,
            "tags": [{"key": "tag1", "value": "value1"}],
        }
    }


@pytest.mark.asyncio
async def test_launch_run_success(mock_client):
    # Setup mock response
    mock_client.execute_graphql.return_value = {
        "data": {
            "launchRun": {
                "__typename": "LaunchRunSuccess",
                "run": {"runId": "new_run_id", "status": "STARTED"},
            }
        }
    }

    # Execute method
    result = await mock_client.launch_run(
        "test_location", "test_repo", "test_job", "{}"
    )

    # Assert result
    assert result["success"] is True
    assert "new_run_id" in result["message"]
    assert result["run"] == {"runId": "new_run_id", "status": "STARTED"}


@pytest.mark.asyncio
async def test_launch_run_invalid_config(mock_client):
    # Execute method with invalid JSON
    result = await mock_client.launch_run(
        "test_location", "test_repo", "test_job", "invalid json"
    )

    # Assert error
    assert result["success"] is False
    assert "Invalid JSON" in result["message"]



#!/usr/bin/env python3
import os
import sys

os.environ['DAGSTER_DEMO_MODE'] = 'true'
sys.path.insert(0, 'src')

try:
    from mcp_dagster.server import mcp
    
    # Try to get tools directly
    if hasattr(mcp, '_tool_manager'):
        tools = mcp._tool_manager._tools
        print(f"✅ MCP Server loaded successfully!")
        print(f"✅ Found {len(tools)} tools:")
        for name, tool in tools.items():
            print(f"  - {name}")
        sys.exit(0)
    else:
        print("❌ Could not find _tool_manager")
        sys.exit(1)
except Exception as e:
    print(f"❌ Error: {e}")
    import traceback
    traceback.print_exc()
    sys.exit(1)


import asyncio

from agents import Agent, ModelSettings, Runner
from agents.mcp import MCPServerSse


async def main():
    conversation_history = []

    async with MCPServerSse(
        name="Dagster MCP Server",
        params={
            "url": "http://0.0.0.0:8000/sse",
        },
    ) as server:
        tools = await server.list_tools()
        print(f"Available tools: {[x.name for x in tools]}")

        agent = Agent(
            name="Dagster Explorer",
            instructions="""You are a Data Engineering Assistant specializing in Dagster workflows.
You help users explore their Dagster instance, monitor pipelines, and troubleshoot issues.
When interacting with the Dagster instance:
1. Start by exploring available repositories, jobs, and assets
2. Provide clear, concise explanations of pipeline components
3. Help users materialize assets and monitor runs
4. Summarize complex Dagster information in a user-friendly way
Always confirm actions before materializing assets or launching jobs.""",
            mcp_servers=[server],
            model_settings=ModelSettings(tool_choice="auto", parallel_tool_calls=True),
        )

        while True:
            user_input = input("\nEnter your question (or 'exit' to quit): ")
            if user_input.lower() == "exit":
                break

            if conversation_history:
                context = "\n".join(conversation_history)
                full_input = (
                    f"Previous conversation:\n{context}\n\nNew question: {user_input}"
                )
            else:
                full_input = user_input

            print("\nProcessing your request...")
            result = await Runner.run(starting_agent=agent, input=full_input)
            print(f"\nResponse: {result.final_output}")

            conversation_history.append(f"User: {user_input}")
            conversation_history.append(f"Assistant: {result.final_output}")


if __name__ == "__main__":
    asyncio.run(main())



#!/usr/bin/env python3
"""Simple test script for MCP server via stdio"""
import asyncio
import json
import os
import sys
import subprocess
from typing import Any

# Set demo mode
os.environ['DAGSTER_DEMO_MODE'] = 'true'

# Add src to path
sys.path.insert(0, os.path.join(os.path.dirname(__file__), 'src'))

async def test_mcp_tools():
    """Test MCP tools via stdio"""
    # Start the MCP server
    proc = await asyncio.create_subprocess_exec(
        sys.executable,
        'src/mcp_dagster/__main__.py',
        stdin=subprocess.PIPE,
        stdout=subprocess.PIPE,
        stderr=subprocess.PIPE,
        env={**os.environ, 'PYTHONPATH': os.path.join(os.path.dirname(__file__), 'src')}
    )
    
    async def send_request(request: dict[str, Any]) -> dict[str, Any]:
        """Send a JSON-RPC request"""
        proc.stdin.write((json.dumps(request) + '\n').encode())
        await proc.stdin.drain()
        
        response_line = await proc.stdout.readline()
        if not response_line:
            raise Exception("No response from server")
        
        return json.loads(response_line.decode())
    
    try:
        # Initialize
        init_req = {
            "jsonrpc": "2.0",
            "id": 1,
            "method": "initialize",
            "params": {
                "protocolVersion": "2024-11-05",
                "capabilities": {},
                "clientInfo": {"name": "test-client", "version": "1.0.0"}
            }
        }
        
        init_response = await send_request(init_req)
        print(f"Initialize response: {init_response.get('result', {}).get('serverInfo', {})}")
        
        # Send initialized notification
        await send_request({
            "jsonrpc": "2.0",
            "method": "notifications/initialized"
        })
        
        # List tools
        tools_req = {
            "jsonrpc": "2.0",
            "id": 2,
            "method": "tools/list"
        }
        
        tools_response = await send_request(tools_req)
        tools = tools_response.get('result', {}).get('tools', [])
        
        print(f"\n✅ Found {len(tools)} tools:")
        for tool in tools:
            print(f"  - {tool.get('name')}: {tool.get('description', 'No description')}")
        
        return len(tools)
        
    finally:
        proc.terminate()
        await proc.wait()


if __name__ == "__main__":
    try:
        count = asyncio.run(test_mcp_tools())
        print(f"\n✅ MCP test passed! Found {count} tools.")
        sys.exit(0)
    except Exception as e:
        print(f"\n❌ MCP test failed: {e}")
        import traceback
        traceback.print_exc()
        sys.exit(1)



#!/usr/bin/env python3
import asyncio
import os
import sys

# Add src to path
sys.path.insert(0, os.path.join(os.path.dirname(__file__), 'src'))

# Set demo mode
os.environ['DAGSTER_DEMO_MODE'] = 'true'

from mcp.server.stdio import stdio_server
from mcp.client.session import ClientSession
from mcp import StdioServerParameters


async def test_mcp():
    """Test the MCP server manually"""
    from mcp_dagster.server import mcp
    
    print("MCP Server loaded successfully!")
    print(f"Server name: {mcp.name if hasattr(mcp, 'name') else 'Unknown'}")
    
    # Get tools list
    tools = mcp._mcp_server._tools if hasattr(mcp, '_mcp_server') else []
    print(f"\nAvailable tools ({len(tools)}):")
    for tool in tools:
        name = tool.name if hasattr(tool, 'name') else str(tool)
        desc = tool.description if hasattr(tool, 'description') else 'No description'
        print(f"  - {name}: {desc}")
    
    return len(tools)


if __name__ == "__main__":
    try:
        count = asyncio.run(test_mcp())
        print(f"\n✅ MCP test passed! Found {count} tools.")
        sys.exit(0)
    except Exception as e:
        print(f"\n❌ MCP test failed: {e}")
        import traceback
        traceback.print_exc()
        sys.exit(1)


from dagster import asset
from pandas import DataFrame, get_dummies, read_html
from sklearn.linear_model import LinearRegression


@asset
def country_populations() -> DataFrame:
    df = read_html("https://tinyurl.com/mry64ebh")[0]
    df.columns = ["country", "pop2022", "pop2023", "change", "continent", "region"]
    df["change"] = df["change"].str.rstrip("%").str.replace("−", "-").astype("float")
    return df


@asset
def continent_change_model(country_populations: DataFrame) -> LinearRegression:
    data = country_populations.dropna(subset=["change"])
    return LinearRegression().fit(get_dummies(data[["continent"]]), data["change"])


@asset
def continent_stats(
    country_populations: DataFrame, continent_change_model: LinearRegression
) -> DataFrame:
    result = country_populations.groupby("continent").sum()
    result["pop_change_factor"] = continent_change_model.coef_
    return result



import json
import os
from typing import Any, Dict, List, Optional, Union

import httpx
from mcp.server.fastmcp import FastMCP


class DagsterGraphqlClient:
    """Client for interacting with Dagster GraphQL API"""

    def __init__(self, graphql_url: str = None):
        if graphql_url is None:
            graphql_url = os.environ.get("DAGSTER_GRAPHQL_URL", "http://localhost:3000/graphql")
        self.graphql_url = graphql_url

    async def execute_graphql(
        self, query: str, variables: Optional[Dict[str, Any]] = None
    ) -> Dict[str, Any]:
        """Execute a GraphQL query against the Dagster API"""
        # Check if in demo mode (for testing without actual Dagster instance)
        if os.environ.get("DAGSTER_DEMO_MODE") == "true":
            return self._demo_response(query, variables)
        
        async with httpx.AsyncClient() as client:
            response = await client.post(
                self.graphql_url, json={"query": query, "variables": variables or {}}
            )
            return response.json()

    def _demo_response(self, query: str, variables: Optional[Dict[str, Any]] = None) -> Dict[str, Any]:
        """Return demo responses for testing without actual Dagster instance"""
        if "repositoriesOrError" in query:
            return {
                "data": {
                    "repositoriesOrError": {
                        "nodes": [
                            {"name": "__repository__", "location": {"name": "__file_location__"}}
                        ]
                    }
                }
            }
        elif "repositoryOrError" in query and "jobs" in query:
            return {
                "data": {
                    "repositoryOrError": {
                        "jobs": [
                            {"name": "example_job", "description": "Example job for demo"}
                        ]
                    }
                }
            }
        elif "repositoryOrError" in query and "assetNodes" in query:
            return {
                "data": {
                    "repositoryOrError": {
                        "assetNodes": [
                            {"assetKey": {"path": ["example_asset"]}, "description": "Example asset"}
                        ]
                    }
                }
            }
        elif "runsOrError" in query:
            return {
                "data": {
                    "runsOrError": {
                        "results": [
                            {
                                "runId": "demo_run_1",
                                "status": "SUCCESS",
                                "jobName": "example_job",
                                "startTime": "2024-01-01T00:00:00",
                                "endTime": "2024-01-01T00:05:00"
                            }
                        ]
                    }
                }
            }
        elif "runOrError" in query:
            return {
                "data": {
                    "runOrError": {
                        "runId": variables.get("runId", "demo_run_1") if variables else "demo_run_1",
                        "status": "SUCCESS",
                        "jobName": "example_job",
                        "startTime": "2024-01-01T00:00:00",
                        "endTime": "2024-01-01T00:05:00",
                        "tags": []
                    }
                }
            }
        elif "launchRun" in query:
            return {
                "data": {
                    "launchRun": {
                        "__typename": "LaunchRunSuccess",
                        "run": {
                            "runId": "demo_run_new",
                            "status": "STARTED"
                        }
                    }
                }
            }
        elif "terminateRun" in query:
            return {
                "data": {
                    "terminateRun": {
                        "__typename": "TerminateRunSuccess",
                        "run": {
                            "runId": variables.get("runId", "demo_run_1") if variables else "demo_run_1",
                            "status": "CANCELED"
                        }
                    }
                }
            }
        elif "assetOrError" in query:
            return {
                "data": {
                    "assetOrError": {
                        "key": {"path": ["example_asset"]},
                        "definition": {
                            "description": "Example asset description",
                            "jobNames": ["example_job"]
                        }
                    }
                }
            }
        return {"data": {}}

    async def list_repositories(self) -> Dict[str, Union[List[Dict[str, str]], str]]:
        """List all available Dagster repositories"""
        query = """
        query {
          repositoriesOrError {
            ... on RepositoryConnection {
              nodes {
                name
                location {
                  name
                }
              }
            }
          }
        }
        """
        result = await self.execute_graphql(query)
        if "errors" in result:
            return {"error": result["errors"][0]["message"]}

        repos = result.get("data", {}).get("repositoriesOrError", {}).get("nodes", [])
        return {
            "repositories": [
                {"name": r["name"], "location": r["location"]["name"]} for r in repos
            ]
        }

    async def list_jobs(
        self, repository_location: str, repository_name: str
    ) -> Dict[str, Any]:
        """List all jobs in a specific repository"""
        query = """
        query JobsQuery($repositoryLocationName: String!, $repositoryName: String!) {
          repositoryOrError(
            repositorySelector: {
              repositoryLocationName: $repositoryLocationName
              repositoryName: $repositoryName
            }
          ) {
            ... on Repository {
              jobs {
                name
                description
              }
            }
          }
        }
        """
        variables = {
            "repositoryLocationName": repository_location,
            "repositoryName": repository_name,
        }

        result = await self.execute_graphql(query, variables)
        if "errors" in result:
            return {"error": result["errors"][0]["message"]}

        jobs = result.get("data", {}).get("repositoryOrError", {}).get("jobs", [])
        return {"jobs": jobs}

    async def list_assets(
        self, repository_location: str, repository_name: str
    ) -> Dict[str, Any]:
        """List all assets in a specific repository"""
        query = """
        query AssetsQuery($repositoryLocationName: String!, $repositoryName: String!) {
          repositoryOrError(
            repositorySelector: {
              repositoryLocationName: $repositoryLocationName
              repositoryName: $repositoryName
            }
          ) {
            ... on Repository {
              assetNodes {
                assetKey {
                  path
                }
                description
              }
            }
          }
        }
        """
        variables = {
            "repositoryLocationName": repository_location,
            "repositoryName": repository_name,
        }

        result = await self.execute_graphql(query, variables)
        if "errors" in result:
            return {"error": result["errors"][0]["message"]}

        assets = (
            result.get("data", {}).get("repositoryOrError", {}).get("assetNodes", [])
        )
        formatted_assets = []
        for asset in assets:
            key = asset.get("assetKey", {}).get("path", [])
            formatted_assets.append(
                {"asset_key": "/".join(key), "description": asset.get("description")}
            )

        return {"assets": formatted_assets}

    async def get_recent_runs(self, limit: int = 10) -> Dict[str, Any]:
        """Get recent Dagster runs"""
        query = """
        query RecentRunsQuery($limit: Int!) {
          runsOrError(limit: $limit) {
            ... on Runs {
              results {
                runId
                status
                jobName
                startTime
                endTime
              }
            }
          }
        }
        """
        variables = {"limit": limit}

        result = await self.execute_graphql(query, variables)
        if "errors" in result:
            return {"error": result["errors"][0]["message"]}

        runs = result.get("data", {}).get("runsOrError", {}).get("results", [])
        return {"runs": runs}

    async def get_run_info(self, run_id: str) -> Dict[str, Any]:
        """Get detailed information about a specific run"""
        query = """
        query RunQuery($runId: ID!) {
          runOrError(runId: $runId) {
            ... on Run {
              runId
              status
              jobName
              startTime
              endTime
              tags {
                key
                value
              }
            }
          }
        }
        """
        variables = {"runId": run_id}

        result = await self.execute_graphql(query, variables)
        if "errors" in result:
            return {"error": result["errors"][0]["message"]}

        run = result.get("data", {}).get("runOrError", {})
        return {"run": run}

    async def launch_run(
        self,
        repository_location: str,
        repository_name: str,
        job_name: str,
        run_config: str = "{}",
    ) -> Dict[str, Any]:
        """Launch a Dagster job run"""
        query = """
        mutation LaunchRunMutation(
          $repositoryLocationName: String!
          $repositoryName: String!
          $jobName: String!
          $runConfigData: RunConfigData!
        ) {
          launchRun(
            executionParams: {
              selector: {
                repositoryLocationName: $repositoryLocationName
                repositoryName: $repositoryName
                jobName: $jobName
              }
              runConfigData: $runConfigData
            }
          ) {
            __typename
            ... on LaunchRunSuccess {
              run {
                runId
                status
              }
            }
            ... on RunConfigValidationInvalid {
              errors {
                message
              }
            }
            ... on PythonError {
              message
            }
          }
        }
        """

        try:
            config_data = json.loads(run_config)
        except json.JSONDecodeError:
            return {
                "success": False,
                "message": f"Invalid JSON in run_config: {run_config}",
            }

        variables = {
            "repositoryLocationName": repository_location,
            "repositoryName": repository_name,
            "jobName": job_name,
            "runConfigData": config_data,
        }

        result = await self.execute_graphql(query, variables)
        if "errors" in result:
            return {"success": False, "message": result["errors"][0]["message"]}

        launch_result = result.get("data", {}).get("launchRun", {})

        if launch_result.get("__typename") == "LaunchRunSuccess":
            run = launch_result.get("run", {})
            return {
                "success": True,
                "message": f"Run launched successfully with ID: {run.get('runId')} (status: {run.get('status')})",
                "run": run,
            }
        elif launch_result.get("__typename") == "RunConfigValidationInvalid":
            errors = [error.get("message") for error in launch_result.get("errors", [])]
            return {
                "success": False,
                "message": f"Config validation error: {'; '.join(errors)}",
            }
        else:
            return {
                "success": False,
                "message": launch_result.get("message", "Unknown error"),
            }

    async def materialize_asset(
        self, asset_key: str, repository_location: str, repository_name: str
    ) -> Dict[str, Any]:
        """Materialize a specific Dagster asset"""
        # Query to get all jobs in the repository
        jobs_query = """
        query JobsQuery($repositoryLocationName: String!, $repositoryName: String!) {
          repositoryOrError(
            repositorySelector: {
              repositoryLocationName: $repositoryLocationName
              repositoryName: $repositoryName
            }
          ) {
            ... on Repository {
              jobs {
                name
              }
            }
          }
        }
        """

        jobs_variables = {
            "repositoryLocationName": repository_location,
            "repositoryName": repository_name,
        }

        jobs_result = await self.execute_graphql(jobs_query, jobs_variables)
        if "errors" in jobs_result:
            return {"success": False, "message": jobs_result["errors"][0]["message"]}

        jobs = jobs_result.get("data", {}).get("repositoryOrError", {}).get("jobs", [])
        if not jobs:
            return {"success": False, "message": "No jobs found in the repository"}

        asset_job_name = None
        for job in jobs:
            if asset_key in job["name"]:
                asset_job_name = job["name"]
                break

        if not asset_job_name:
            for job in jobs:
                if any(
                    keyword in job["name"].lower()
                    for keyword in ["materialize", "asset", "build"]
                ):
                    asset_job_name = job["name"]
                    break

        if not asset_job_name and jobs:
            asset_job_name = jobs[0]["name"]

        if not asset_job_name:
            return {
                "success": False,
                "message": "Could not determine which job to use for asset materialization",
            }

        launch_query = """
        mutation LaunchRunMutation(
          $repositoryLocationName: String!
          $repositoryName: String!
          $jobName: String!
        ) {
          launchRun(
            executionParams: {
              selector: {
                repositoryLocationName: $repositoryLocationName
                repositoryName: $repositoryName
                jobName: $jobName
              }
            }
          ) {
            __typename
            ... on LaunchRunSuccess {
              run {
                runId
                status
              }
            }
            ... on PythonError {
              message
            }
          }
        }
        """

        launch_variables = {
            "repositoryLocationName": repository_location,
            "repositoryName": repository_name,
            "jobName": asset_job_name,
        }

        launch_result = await self.execute_graphql(launch_query, launch_variables)
        if "errors" in launch_result:
            return {"success": False, "message": launch_result["errors"][0]["message"]}

        run_data = launch_result.get("data", {}).get("launchRun", {})

        if run_data.get("__typename") == "LaunchRunSuccess":
            run = run_data.get("run", {})
            return {
                "success": True,
                "message": f"Job started for asset materialization with run ID: {run.get('runId')} (status: {run.get('status')})",
                "run": run,
            }
        else:
            return {
                "success": False,
                "message": run_data.get("message", "Unknown error"),
            }

    async def terminate_run(self, run_id: str) -> Dict[str, Any]:
        """Terminate an in-progress Dagster run"""
        query = """
        mutation TerminateRunMutation($runId: ID!) {
          terminateRun(runId: $runId) {
            __typename
            ... on TerminateRunSuccess {
              run {
                runId
                status
              }
            }
            ... on TerminateRunFailure {
              message
            }
            ... on RunNotFoundError {
              runId
            }
            ... on PythonError {
              message
            }
          }
        }
        """

        variables = {"runId": run_id}

        result = await self.execute_graphql(query, variables)
        if "errors" in result:
            return {"success": False, "message": result["errors"][0]["message"]}

        terminate_result = result.get("data", {}).get("terminateRun", {})

        if terminate_result.get("__typename") == "TerminateRunSuccess":
            run = terminate_result.get("run", {})
            return {
                "success": True,
                "message": f"Run {run.get('runId')} terminated successfully (new status: {run.get('status')})",
                "run": run,
            }
        elif terminate_result.get("__typename") == "RunNotFoundError":
            return {
                "success": False,
                "message": f"Run with ID {terminate_result.get('runId')} not found",
            }
        else:
            return {
                "success": False,
                "message": terminate_result.get("message", "Unknown error"),
            }

    async def get_asset_info(self, asset_key: str) -> Dict[str, Any]:
        """Get detailed information about a specific asset"""
        query = """
        query AssetQuery($assetKey: AssetKeyInput!) {
          assetOrError(assetKey: $assetKey) {
            ... on Asset {
              key {
                path
              }
              definition {
                description
              }
            }
            ... on AssetNotFoundError {
              message
            }
          }
        }
        """

        asset_key_parts = asset_key.split("/")
        variables = {"assetKey": {"path": asset_key_parts}}

        result = await self.execute_graphql(query, variables)
        if "errors" in result:
            return {"error": result["errors"][0]["message"]}

        asset_data = result.get("data", {}).get("assetOrError", {})

        if "message" in asset_data:
            return {"error": asset_data["message"]}

        formatted_asset = {
            "asset_key": "/".join(asset_data.get("key", {}).get("path", [])),
            "description": asset_data.get("definition", {}).get("description"),
        }
        jobs_query = """
        query AssetJobsQuery($assetKey: AssetKeyInput!) {
          assetOrError(assetKey: $assetKey) {
            ... on Asset {
              definition {
                jobNames
              }
            }
          }
        }
        """

        jobs_result = await self.execute_graphql(jobs_query, variables)
        if "errors" not in jobs_result:
            jobs_data = (
                jobs_result.get("data", {})
                .get("assetOrError", {})
                .get("definition", {})
            )
            if "jobNames" in jobs_data:
                formatted_asset["materialized_by_jobs"] = jobs_data["jobNames"]

        return formatted_asset


mcp = FastMCP(
    "Dagster Explorer",
    instructions="A simple MCP server for Dagster",
    dependencies=["httpx"],
)
dagster_client = DagsterGraphqlClient()


@mcp.tool()
async def list_repositories() -> dict:
    """List all available Dagster repositories"""
    return await dagster_client.list_repositories()


@mcp.tool()
async def list_jobs(repository_location: str, repository_name: str) -> dict:
    """List all jobs in a specific repository"""
    return await dagster_client.list_jobs(repository_location, repository_name)


@mcp.tool()
async def list_assets(repository_location: str, repository_name: str) -> dict:
    """List all assets in a specific repository"""
    return await dagster_client.list_assets(repository_location, repository_name)


@mcp.tool()
async def recent_runs(limit: int = 10) -> dict:
    """Get recent Dagster runs"""
    return await dagster_client.get_recent_runs(limit)


@mcp.tool()
async def get_run_info(run_id: str) -> dict:
    """Get detailed information about a specific run"""
    return await dagster_client.get_run_info(run_id)


@mcp.tool()
async def launch_run(
    repository_location: str,
    repository_name: str,
    job_name: str,
    run_config: str = "{}",
) -> dict:
    """Launch a Dagster job run"""
    return await dagster_client.launch_run(
        repository_location, repository_name, job_name, run_config
    )


@mcp.tool()
async def materialize_asset(
    asset_key: str, repository_location: str, repository_name: str
) -> dict:
    """Materialize a specific Dagster asset"""
    return await dagster_client.materialize_asset(
        asset_key, repository_location, repository_name
    )


@mcp.tool()
async def terminate_run(run_id: str) -> dict:
    """Terminate an in-progress Dagster run"""
    return await dagster_client.terminate_run(run_id)


@mcp.tool()
async def get_asset_info(asset_key: str) -> dict:
    """Get detailed information about a specific asset"""
    return await dagster_client.get_asset_info(asset_key)


if __name__ == "__main__":
    # Run with configurable transport (supports stdio and sse)
    transport = os.environ.get("DAGSTER_TRANSPORT", "stdio")
    mcp.run(transport=transport)